from django import forms
from django.forms import ModelForm

from web.models.worker import role_choices_by_worker_type
from web.models import Worker, WorkerStudyRole
from web.models.constants import GLOBAL_STUDY_ID
from web.models.worker_study_role import WORKER_STAFF


class WorkerForm(ModelForm):
    class Meta:
        model = Worker
        exclude = ['appointments']

    def __init__(self, *args, **kwargs):
        worker_type = kwargs.pop('worker_type', WORKER_STAFF)
        choices = role_choices_by_worker_type(worker_type)
        super(WorkerForm, self).__init__(*args, **kwargs)
        self.fields['role'] = forms.ChoiceField(label='Role', choices=choices)

    def save(self, commit=True):
        instance = super(WorkerForm, self).save(commit)
        roles = WorkerStudyRole.objects.filter(worker=instance, study_id=GLOBAL_STUDY_ID)
        if roles.count() > 0:
            roles.update(role=self.cleaned_data['role'])
        else:
            WorkerStudyRole.objects.create(worker=instance, study_id=GLOBAL_STUDY_ID, role=self.cleaned_data['role'])
